@@ -6,7 +6,7 @@ use warnings;
 use utf8;
 use Carp ();
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # first, our giant data structure
 our %state_abbr = (
@@ -20,7 +20,7 @@ our %state_abbr = (
         co => {text => 'Colorado',       capital => 'Denver'},
         ct => {text => 'Connecticut',    capital => 'Hartford'},
         de => {text => 'Delaware',       capital => 'Dover'},
-        dc => {text => 'District of Columbia', capital => undef },
+        dc => {text => 'District of Columbia', capital => '' },
         fl => {text => 'Florida',        capital => 'Tallahassee'},
         ga => {text => 'Georgia',        capital => 'Atlanta'},
         gu => {text => 'Guam',           capital => 'Hagåtña'},
@@ -73,7 +73,7 @@ our %state_abbr = (
         bc => {text => 'British Columbia',          capital => 'Victoria'},
         mb => {text => 'Manitoba',                  capital => 'Winnipeg'},
         nb => {text => 'New Brunswick',             capital => 'Fredericton'},
-        nl => {text => 'Newfoundland and Labrador', capital => q<St. John's>},
+        nl => {text => 'Newfoundland and Labrador', capital => q<St. John\'s>},
         ns => {text => 'Nova Scotia',               capital => 'Halifax'},
         nt => {text => 'Northwest Territories',     capital => 'Yellowknife'},
         nu => {text => 'Nunavut',                   capital => 'Iqaluit'},
@@ -122,15 +122,15 @@ sub find {
 
     # if we have already blessed code for this state, return it
     # this avoids redefining the same subroutines
-    return $objects{$state} if $objects{$state};
+    (my $subclass = $state) =~ s/\s/::/g;
+    return $objects{$subclass} if $objects{$subclass};
 
     my $data = length($state) == 2 ?    #
       $state_abbr{$country}{$state}
       : $state_name{$country}{$state}
       or return undef;
 
-    $state =~ s/\s/::/g;
-    my $class = ref($self) . "::$state";
+    my $class = ref($self) . "::$subclass";
 
     # and basically here I've done something similar
     #   to what I read in the Mojo::Base attributes code
@@ -141,7 +141,7 @@ sub find {
     }
     eval "$code;1" or Carp::croak "Geo::States error: $@";
     my $ref = bless(\$code, $class);
-    $objects{$state} = $ref;
+    $objects{$subclass} = $ref;
     $ref;
 }
 
